@@ -382,10 +382,12 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'brand-protection/url-info')
     self.add('AUTH', 'accounts', 'cfd_tunnel')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'configurations')
+    self.add('AUTH', 'accounts', 'cfd_tunnel', 'connectors')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'connections')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'management')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'token')
     self.add('AUTH', 'accounts', 'custom_pages')
+
     self.add('VOID', 'accounts', 'dlp')
     self.add('VOID', 'accounts', 'dlp/patterns')
     self.add('AUTH', 'accounts', 'dlp/patterns/validate')
@@ -419,6 +421,14 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint')
     self.add('AUTH', 'accounts', 'rulesets/phases', 'entrypoint/versions')
     self.add('AUTH', 'accounts', 'rulesets/phases', 'versions')
+
+    self.add('VOID', 'accounts', 'rum')
+    self.add('AUTH', 'accounts', 'rum/site_info')
+    self.add('AUTH', 'accounts', 'rum/site_info/list')
+    self.add('VOID', 'accounts', 'rum/v2')
+    self.add('AUTH', 'accounts', 'rum/v2', 'rule')
+    self.add('AUTH', 'accounts', 'rum/v2', 'rules')
+
     self.add('VOID', 'accounts', 'storage')
     self.add('AUTH', 'accounts', 'storage/analytics')
     self.add('AUTH', 'accounts', 'storage/analytics/stored')
@@ -428,6 +438,7 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'keys')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'values')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'metadata')
+
     self.add('AUTH', 'accounts', 'subscriptions')
     self.add('AUTH', 'accounts', 'tunnels')
     self.add('AUTH', 'accounts', 'tunnels', 'connections')
@@ -444,6 +455,8 @@ def accounts(self):
     self.add('VOID', 'accounts', 'workers/dispatch')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'content')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'settings')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'tags')
     self.add('AUTH', 'accounts', 'workers/domains')
     self.add('VOID', 'accounts', 'workers/durable_objects')
@@ -452,9 +465,15 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'workers/queues')
     self.add('AUTH', 'accounts', 'workers/queues', 'consumers')
     self.add('AUTH', 'accounts', 'workers/scripts')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'content')
     self.add('AUTH', 'accounts', 'workers/scripts', 'schedules')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'settings')
     self.add('AUTH', 'accounts', 'workers/scripts', 'tails')
     self.add('AUTH', 'accounts', 'workers/scripts', 'usage-model')
+    self.add('VOID', 'accounts', 'workers/services')
+    self.add('VOID', 'accounts', 'workers/services', 'environments')
+    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'content')
+    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'settings')
     self.add('AUTH', 'accounts', 'workers/subdomain')
 
 def accounts_addressing(self):
@@ -469,6 +488,7 @@ def accounts_addressing(self):
     self.add('AUTH', 'accounts', 'addressing/loa_documents', 'download')
     self.add('AUTH', 'accounts', 'addressing/prefixes')
     self.add('VOID', 'accounts', 'addressing/prefixes', 'bgp')
+    self.add('AUTH', 'accounts', 'addressing/prefixes', 'bgp/prefixes')
     self.add('AUTH', 'accounts', 'addressing/prefixes', 'bgp/status')
     self.add('AUTH', 'accounts', 'addressing/prefixes', 'bindings')
     self.add('AUTH', 'accounts', 'addressing/prefixes', 'delegations')
@@ -516,6 +536,8 @@ def accounts_stream(self):
     """ accounts stream """
 
     self.add('AUTH', 'accounts', 'stream')
+    self.add('AUTH', 'accounts', 'stream', 'audio')
+    self.add('AUTH', 'accounts', 'stream', 'audio/copy')
     self.add('AUTH', 'accounts', 'stream', 'captions')
     self.add('AUTH', 'accounts', 'stream', 'embed')
     self.add('AUTH', 'accounts', 'stream', 'downloads')
@@ -572,6 +594,7 @@ def accounts_access(self):
 
     self.add('VOID', 'accounts', 'access')
 #   self.add('AUTH', 'accounts', 'access/bookmarks') # deprecated 2023-03-19
+    self.add('AUTH', 'accounts', 'access/custom_pages')
     self.add('AUTH', 'accounts', 'access/gateway_ca')
     self.add('AUTH', 'accounts', 'access/groups')
     self.add('AUTH', 'accounts', 'access/identity_providers')
@@ -632,6 +655,7 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'custom_ns/verify')
 
     self.add('AUTH', 'accounts', 'devices')
+
     self.add('AUTH', 'accounts', 'devices', 'override_codes')
     self.add('AUTH', 'accounts', 'devices/dex_tests')
     self.add('AUTH', 'accounts', 'devices/networks')
@@ -649,6 +673,14 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'devices/settings')
     self.add('AUTH', 'accounts', 'devices/unrevoke')
 
+    self.add('VOID', 'accounts', 'dex')
+    self.add('AUTH', 'accounts', 'dex/http-tests')
+    self.add('AUTH', 'accounts', 'dex/tests')
+    self.add('AUTH', 'accounts', 'dex/tests/unique-devices')
+    self.add('VOID', 'accounts', 'dex/traceroute-test-results')
+    self.add('AUTH', 'accounts', 'dex/traceroute-test-results', 'network-path')
+    self.add('AUTH', 'accounts', 'dex/traceroute-tests')
+    self.add('AUTH', 'accounts', 'dex/traceroute-tests', 'network-path')
 
     self.add('AUTH', 'accounts', 'dns_firewall')
     self.add('VOID', 'accounts', 'dns_firewall', 'dns_analytics')
@@ -669,10 +701,11 @@ def accounts_extras(self):
     self.add('VOID', 'accounts', 'images')
     self.add('AUTH', 'accounts', 'images/v1')
     self.add('AUTH', 'accounts', 'images/v1', 'blob')
+    self.add('AUTH', 'accounts', 'images/v1/config')
     self.add('AUTH', 'accounts', 'images/v1/keys')
     self.add('AUTH', 'accounts', 'images/v1/stats')
     self.add('AUTH', 'accounts', 'images/v1/variants')
-    self.add('VOID', 'accounts', 'images/v2')
+    self.add('AUTH', 'accounts', 'images/v2')
     self.add('AUTH', 'accounts', 'images/v2/direct_upload')
 
     self.add('VOID', 'accounts', 'intel')
@@ -684,6 +717,7 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'intel/domain')
     self.add('AUTH', 'accounts', 'intel/domain-history')
     self.add('AUTH', 'accounts', 'intel/domain/bulk')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds')
     self.add('AUTH', 'accounts', 'intel/ip')
     self.add('AUTH', 'accounts', 'intel/ip-list')
     self.add('AUTH', 'accounts', 'intel/miscategorization')
@@ -716,6 +750,11 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'teamnet/routes/network')
     self.add('AUTH', 'accounts', 'teamnet/virtual_networks')
 
+    self.add('VOID', 'accounts', 'urlscanner')
+    self.add('AUTH', 'accounts', 'urlscanner/scan')
+    self.add('AUTH', 'accounts', 'urlscanner/scan', 'har')
+    self.add('AUTH', 'accounts', 'urlscanner/scan', 'screenshot')
+
 def zones_extras(self):
     """ zones extras """
 
@@ -742,6 +781,13 @@ def zones_extras(self):
     self.add('AUTH', 'zones', 'rulesets/phases', 'versions')
     self.add('AUTH', 'zones', 'url_normalization')
 
+    self.add('VOID', 'zones', 'hostnames')
+    self.add('AUTH', 'zones', 'hostnames/settings')
+    self.add('AUTH', 'zones', 'snippets')
+    self.add('AUTH', 'zones', 'snippets', 'content')
+    self.add('AUTH', 'zones', 'snippets/snippet_rules')
+
+
 def zones_web3(self):
     """ zones web3 """
 
@@ -788,7 +834,10 @@ def zones_api_gateway(self):
 
 def radar(self):
     """ radar """
+
     self.add('VOID', 'radar')
+    self.add('AUTH', 'radar/alerts')
+    self.add('AUTH', 'radar/alerts/locations')
     self.add('VOID', 'radar/annotations')
     self.add('AUTH', 'radar/annotations/outages')
     self.add('AUTH', 'radar/annotations/outages/locations')
@@ -801,6 +850,7 @@ def radar(self):
     self.add('AUTH', 'radar/as112/summary/protocol')
     self.add('AUTH', 'radar/as112/summary/query_type')
     self.add('AUTH', 'radar/as112/summary/response_codes')
+
     self.add('AUTH', 'radar/as112/timeseries')
     self.add('AUTH', 'radar/as112/timeseries/dnssec')
     self.add('AUTH', 'radar/as112/timeseries/edns')
@@ -808,6 +858,15 @@ def radar(self):
     self.add('AUTH', 'radar/as112/timeseries/protocol')
     self.add('AUTH', 'radar/as112/timeseries/query_type')
     self.add('AUTH', 'radar/as112/timeseries/response_codes')
+
+    self.add('VOID', 'radar/as112/timeseries_groups')
+    self.add('AUTH', 'radar/as112/timeseries_groups/dnssec')
+    self.add('AUTH', 'radar/as112/timeseries_groups/edns')
+    self.add('AUTH', 'radar/as112/timeseries_groups/ip_version')
+    self.add('AUTH', 'radar/as112/timeseries_groups/protocol')
+    self.add('AUTH', 'radar/as112/timeseries_groups/query_type')
+    self.add('AUTH', 'radar/as112/timeseries_groups/response_codes')
+
     self.add('VOID', 'radar/as112/top')
     self.add('AUTH', 'radar/as112/top/locations')
     self.add('AUTH', 'radar/as112/top/locations/dnssec')
@@ -853,9 +912,14 @@ def radar(self):
     self.add('AUTH', 'radar/bgp/timeseries')
     self.add('VOID', 'radar/bgp/top')
     self.add('AUTH', 'radar/bgp/top/ases')
+    self.add('AUTH', 'radar/bgp/top/ases/prefixes')
     self.add('AUTH', 'radar/bgp/top/prefixes')
     self.add('VOID', 'radar/bgp/hijacks')
     self.add('AUTH', 'radar/bgp/hijacks/events')
+    self.add('VOID', 'radar/bgp/routes')
+    self.add('AUTH', 'radar/bgp/routes/moas')
+    self.add('AUTH', 'radar/bgp/routes/pfx2as')
+    self.add('AUTH', 'radar/bgp/routes/stats')
 
     self.add('AUTH', 'radar/datasets')
     self.add('AUTH', 'radar/datasets/download')
@@ -883,6 +947,16 @@ def radar(self):
     self.add('AUTH', 'radar/email/security/timeseries/spam')
     self.add('AUTH', 'radar/email/security/timeseries/spf')
     self.add('AUTH', 'radar/email/security/timeseries/threat_category')
+
+    self.add('VOID', 'radar/email/security/timeseries_groups')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/arc')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/dkim')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/dmarc')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/malicious')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/spam')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/spf')
+    self.add('AUTH', 'radar/email/security/timeseries_groups/threat_category')
+
     self.add('VOID', 'radar/email/security/top')
     self.add('AUTH', 'radar/email/security/top/ases')
     self.add('AUTH', 'radar/email/security/top/ases/arc')
@@ -901,7 +975,9 @@ def radar(self):
 
     self.add('VOID', 'radar/entities')
     self.add('AUTH', 'radar/entities/asns')
+    self.add('AUTH', 'radar/entities/asns', 'rel')
     self.add('AUTH', 'radar/entities/asns/ip')
+    self.add('AUTH', 'radar/entities/ip')
     self.add('AUTH', 'radar/entities/locations')
 
     self.add('VOID', 'radar/http')
@@ -954,13 +1030,39 @@ def radar(self):
     self.add('AUTH', 'radar/performance/iqi/summary')
     self.add('AUTH', 'radar/performance/iqi/timeseries_groups')
 
+    self.add('VOID', 'radar/quality')
+    self.add('VOID', 'radar/quality/iqi')
+    self.add('AUTH', 'radar/quality/iqi/summary')
+    self.add('AUTH', 'radar/quality/iqi/timeseries_groups')
+    self.add('VOID', 'radar/quality/speed')
+    self.add('AUTH', 'radar/quality/speed/histogram')
+    self.add('AUTH', 'radar/quality/speed/summary')
+    self.add('VOID', 'radar/quality/speed/top')
+    self.add('AUTH', 'radar/quality/speed/top/ases')
+    self.add('AUTH', 'radar/quality/speed/top/locations')
+
     self.add('VOID', 'radar/ranking')
     self.add('AUTH', 'radar/ranking/domain')
     self.add('AUTH', 'radar/ranking/timeseries')
+    self.add('AUTH', 'radar/ranking/timeseries_groups')
     self.add('AUTH', 'radar/ranking/top')
+
     self.add('VOID', 'radar/search')
     self.add('AUTH', 'radar/search/global')
+
     self.add('AUTH', 'radar/specialevents')
+
+    self.add('VOID', 'radar/http/timeseries_groups')
+    self.add('AUTH', 'radar/http/timeseries_groups/bot_class')
+    self.add('AUTH', 'radar/http/timeseries_groups/browser')
+    self.add('AUTH', 'radar/http/timeseries_groups/browser_family')
+    self.add('AUTH', 'radar/http/timeseries_groups/device_type')
+    self.add('AUTH', 'radar/http/timeseries_groups/http_protocol')
+    self.add('AUTH', 'radar/http/timeseries_groups/http_version')
+    self.add('AUTH', 'radar/http/timeseries_groups/ip_version')
+    self.add('AUTH', 'radar/http/timeseries_groups/os')
+    self.add('AUTH', 'radar/http/timeseries_groups/tls_version')
+
     self.add('VOID', 'radar/verified_bots')
     self.add('VOID', 'radar/verified_bots/top')
     self.add('AUTH', 'radar/verified_bots/top/bots')
@@ -971,9 +1073,6 @@ def from_developers(self):
     self.add('VOID', 'accounts', 'analytics_engine')
     self.add('AUTH', 'accounts', 'analytics_engine/sql')
 
-    self.add('AUTH', 'accounts', 'images/v1/config')
-#   self.add('AUTH', 'accounts', 'images/v1/direct_upload') # deprecated 2022-07-01 - expired!
-
     self.add('VOID', 'accounts', 'logpush')
     self.add('AUTH', 'accounts', 'logpush/jobs')
     self.add('VOID', 'accounts', 'logpush/datasets')
